==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Petteri <petteri@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Muokkaa tätä sivua';
$lang['btn_source'] = 'Näytä sivun lähdekoodi';
$lang['btn_show']   = 'Näytä sivu';
$lang['btn_create'] = 'Luo tämä sivu';
$lang['btn_search'] = 'Etsi';
$lang['btn_save']   = 'Tallenna';
$lang['btn_preview']= 'Esikatselu';
$lang['btn_top']    = 'Takaisin ylös';
$lang['btn_revs']   = 'Vanhat versiot';
$lang['btn_recent'] = 'Viimeiset muutokset';
$lang['btn_upload'] = 'Lähetä tiedosto';
$lang['btn_cancel'] = 'Peru';
$lang['btn_index']  = 'Hakemisto';
$lang['btn_secedit']= 'Muokkaa';
$lang['btn_login']  = 'Kirjaudu sisään';
$lang['btn_logout'] = 'Kirjaudu ulos';

$lang['loggedinas'] = 'Kirjautunut nimellä';
$lang['user']       = 'Käyttäjänimi';
$lang['pass']       = 'Salasana';
$lang['fullname']   = 'Kokonimi';
$lang['email']      = 'Sähköposti';
$lang['register']   = 'Rekisteröidy';
$lang['badlogin']   = 'Anteeksi, käyttäjänimi tai salasana oli väärä.';

$lang['regmissing'] = 'Anteeksi, sinun täytyy täyttää kaikki kentät.';
$lang['reguexists'] = 'Anteeksi, käyttäjä tällä käyttäjänimellä on jo olemassa';
$lang['regsuccess'] = 'Käyttäjä luotiin ja salasana lähetettiin sähköpostilla';
$lang['regmailfail']= 'Näyttää siltä, että tuli virheitä salasanan lähettämisessä 
sähköpostiin. Ota yhteys ylläpitäjään!';
$lang['regbadmail'] = 'Antamasi sähköposti näyttää epäkelvolta. Jos pidät tätä virheenä ota yhteys ylläpitäjään.';
$lang['regpwmail']  = 'Sinun DokuWiki salasanasi';
$lang['reghere']    = 'Sinulla ei ole vielä käyttäjätiliä? Hanki sellainen';

$lang['txt_upload']   = 'Valitse tiedosto lähetettäväksi';
$lang['txt_filename'] = 'Syötä wikinimi (valinnainen)';
$lang['lockedby']     = 'Tällä hetkellä tiedoston on lukinnnut';
$lang['lockexpire']   = 'Lukitus päättyy';
$lang['willexpire']   = 'Sinun lukitus tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';

$lang['notsavedyet'] = 'Dokumentissa on tallentamattomia muutoksia, jotka häviävät.\n Haluatko varmasti jatkaa?';
$lang['rssfailed']   = 'Virhe tapahtui noudettaessa tätä syötettä: ';
$lang['nothingfound']= 'Mitään ei löydetty.';

$lang['mediaselect'] = 'Mediatiedoston valinta';
$lang['fileupload']  = 'Mediatiedoston lähetys';
$lang['uploadsucc']  = 'Tiedoston lähetys onnistui';
$lang['uploadfail']  = 'Tiedoston lähetys epäonnistui. Ehkä väärät oikeudet?';
$lang['uploadwrong'] = 'Tiedoston lähetys evätty. Tämä tiedostopääte on kielletty';
$lang['namespaces']  = 'Nimiavaruudet';
$lang['mediafiles']  = 'Tarjolla olevat tiedostot';

$lang['hits']       = 'Osumia';
$lang['quickhits']  = 'Sopivat sivunimet';
$lang['toc']        = 'Sisällysluettelo';
$lang['current']    = 'nykyinen';
$lang['yours']      = 'Sinun versiosi';
$lang['diff']       = 'näytä eroavaisuudet nykyiseen versioon';
$lang['line']       = 'Viiva';
$lang['breadcrumb'] = 'Jäljet';
$lang['lastmod']    = 'Viimeksi muutettu';
$lang['deleted']    = 'poistettu';
$lang['created']    = 'luotu';
$lang['restored']   = 'vanhat versiot palautettu';
$lang['summary']    = 'Yhteenveto muokkauksesta';

$lang['mail_newpage'] = 'sivu lisätty:';
$lang['mail_changed'] = 'sivu muutettu:';

$lang['nosmblinks'] = 'Linkit windows-jakoihin toimivat vain Microsof Internet Explorerilla.\nVoit silti kopioida ja liittää linkin.';

$lang['qb_alert']   = 'Syötä teksti jonka haluat muotoilla.\nSe lisätään dokumentin loppuun.';
$lang['qb_bold']    = 'Lihavoitu teksti';
$lang['qb_italic']  = 'Kursivoitu teksti';
$lang['qb_underl']  = 'Alleviivattu teksti';
$lang['qb_code']    = 'Kooditeksti';
$lang['qb_h1']      = 'Taso 1 otsikko';
$lang['qb_h2']      = 'Taso 2 otsikko';
$lang['qb_h3']      = 'Taso 3 otsikko';
$lang['qb_h4']      = 'Taso 4 otsikko';
$lang['qb_h5']      = 'Taso 5 otsikko';
$lang['qb_link']    = 'Sisäinen linkki';
$lang['qb_extlink'] = 'Ulkoinen linkki';
$lang['qb_hr']      = 'Vaakaeroitin';
$lang['qb_ol']      = 'Järjestetyn listan osa ';
$lang['qb_ul']      = 'Epäjärjestetyn listan osa';
$lang['qb_media']   = 'Lisää kuvia ja muita tiedostoja';
$lang['qb_sig']     = 'Lisää allekirjoitus';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Petteri <petteri@gmail.com>
 * @author     Matti Pöllä <mpo@iki.fi>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Muokkaa tätä sivua';
$lang['btn_source'] = 'Näytä sivun lähdekoodi';
$lang['btn_show']   = 'Näytä sivu';
$lang['btn_create'] = 'Luo tämä sivu';
$lang['btn_search'] = 'Etsi';
$lang['btn_save']   = 'Tallenna';
$lang['btn_preview']= 'Esikatselu';
$lang['btn_top']    = 'Takaisin ylös';
$lang['btn_revs']   = 'Vanhat versiot';
$lang['btn_recent'] = 'Viimeiset muutokset';
$lang['btn_upload'] = 'Lähetä tiedosto';
$lang['btn_cancel'] = 'Peru';
$lang['btn_admin']  = 'Ylläpito';
$lang['btn_update'] = 'Päivitä';
$lang['btn_delete'] = 'Poista';
$lang['btn_back']   = 'Takaisin';
$lang['btn_backlink'] = "Paluulinkit";
$lang['btn_index']  = 'Hakemisto';
$lang['btn_secedit']= 'Muokkaa';
$lang['btn_login']  = 'Kirjaudu sisään';
$lang['btn_logout'] = 'Kirjaudu ulos';
$lang['btn_subscribe'] = 'Tarkkaile';
$lang['btn_unsubscribe'] = 'Lopeta tarkkailu';

$lang['loggedinas'] = 'Kirjautunut nimellä';
$lang['user']       = 'Käyttäjänimi';
$lang['pass']       = 'Salasana';
$lang['passchk']    = 'uudelleen';
$lang['remember']   = 'Muista minut';
$lang['fullname']   = 'Kokonimi';
$lang['email']      = 'Sähköposti';
$lang['register']   = 'Rekisteröidy';
$lang['badlogin']   = 'Käyttäjänimi tai salasana oli väärä.';
$lang['minoredit']  = 'Pieni muutos';

$lang['regmissing'] = 'Anteeksi, sinun täytyy täyttää kaikki kentät.';
$lang['reguexists'] = 'Anteeksi, käyttäjä tällä käyttäjänimellä on jo olemassa';
$lang['regsuccess'] = 'Käyttäjä luotiin ja salasana lähetettiin sähköpostilla';
$lang['regmailfail']= 'Näyttää siltä, että tuli virheitä salasanan lähettämisessä 
sähköpostiin. Ota yhteys ylläpitäjään!';
$lang['regbadmail'] = 'Antamasi sähköposti näyttää epäkelvolta. Jos pidät tätä virheenä ota yhteys ylläpitäjään.';
$lang['regpwmail']  = 'Sinun DokuWiki salasanasi';
$lang['reghere']    = 'Sinulla ei ole vielä käyttäjätiliä? Hanki sellainen';

$lang['txt_upload']   = 'Valitse tiedosto lähetettäväksi';
$lang['txt_filename'] = 'Syötä wikinimi (valinnainen)';
$lang['lockedby']     = 'Tällä hetkellä tiedoston on lukinnnut';
$lang['lockexpire']   = 'Lukitus päättyy';
$lang['willexpire']   = 'Sinun lukitus tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';

$lang['notsavedyet'] = 'Dokumentissa on tallentamattomia muutoksia, jotka häviävät.\n Haluatko varmasti jatkaa?';
$lang['rssfailed']   = 'Virhe tapahtui noudettaessa tätä syötettä: ';
$lang['nothingfound']= 'Mitään ei löydetty.';

$lang['mediaselect'] = 'Mediatiedoston valinta';
$lang['fileupload']  = 'Mediatiedoston lähetys';
$lang['uploadsucc']  = 'Tiedoston lähetys onnistui';
$lang['uploadfail']  = 'Tiedoston lähetys epäonnistui. Ehkä väärät oikeudet?';
$lang['uploadwrong'] = 'Tiedoston lähetys evätty. Tämä tiedostopääte on kielletty';
$lang['namespaces']  = 'Nimiavaruudet';
$lang['mediafiles']  = 'Tarjolla olevat tiedostot';

$lang['hits']       = 'Osumia';
$lang['quickhits']  = 'Sopivat sivunimet';
$lang['toc']        = 'Sisällysluettelo';
$lang['current']    = 'nykyinen';
$lang['yours']      = 'Sinun versiosi';
$lang['diff']       = 'näytä eroavaisuudet nykyiseen versioon';
$lang['line']       = 'Viiva';
$lang['breadcrumb'] = 'Jäljet';
$lang['lastmod']    = 'Viimeksi muutettu';
$lang['deleted']    = 'poistettu';
$lang['created']    = 'luotu';
$lang['restored']   = 'vanhat versiot palautettu';
$lang['summary']    = 'Yhteenveto muokkauksesta';

$lang['mail_newpage'] = 'sivu lisätty:';
$lang['mail_changed'] = 'sivu muutettu:';

$lang['nosmblinks'] = 'Linkit windows-jakoihin toimivat vain Microsof Internet Explorerilla.\nVoit silti kopioida ja liittää linkin.';

$lang['qb_alert']   = 'Syötä teksti jonka haluat muotoilla.\nSe lisätään dokumentin loppuun.';
$lang['qb_bold']    = 'Lihavoitu teksti';
$lang['qb_italic']  = 'Kursivoitu teksti';
$lang['qb_underl']  = 'Alleviivattu teksti';
$lang['qb_code']    = 'Kooditeksti';
$lang['qb_h1']      = 'Taso 1 otsikko';
$lang['qb_h2']      = 'Taso 2 otsikko';
$lang['qb_h3']      = 'Taso 3 otsikko';
$lang['qb_h4']      = 'Taso 4 otsikko';
$lang['qb_h5']      = 'Taso 5 otsikko';
$lang['qb_link']    = 'Sisäinen linkki';
$lang['qb_extlink'] = 'Ulkoinen linkki';
$lang['qb_hr']      = 'Vaakaeroitin';
$lang['qb_ol']      = 'Järjestetyn listan osa ';
$lang['qb_ul']      = 'Epäjärjestetyn listan osa';
$lang['qb_media']   = 'Lisää kuvia ja muita tiedostoja';
$lang['qb_sig']     = 'Lisää allekirjoitus';

//Setup VIM: ex: et ts=2 enc=utf-8 :
